@@ -31,9 +31,7 @@ import java.awt.AWTEvent;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Component;
-import java.awt.Container;
 import java.awt.Dimension;
-import java.awt.FocusTraversalPolicy;
 import java.awt.Graphics;
 import java.awt.Image;
 import java.awt.Point;
@@ -87,35 +85,17 @@ class DataSourceWindowTabbedPane extends JTabbedPane {
     CloseButtonListener.install();
     //Bugfix #28263: Disable focus.
     setFocusable(false);
-    setFocusCycleRoot(true);
-    setFocusTraversalPolicy(new CBTPPolicy());
-  }
-  
-  private Component sel() {
-      Component c = getSelectedComponent();
-      return c == null ? this : c;
+
+    // VisualVM bugfix #279 - do not override FocusTraversalPolicy
+//    setFocusCycleRoot(true);
+//    setFocusTraversalPolicy(new CBTPPolicy());
   }
 
-  private class CBTPPolicy extends FocusTraversalPolicy {
-      public Component getComponentAfter(Container aContainer, Component aComponent) {
-          return sel();
-      }
 
-      public Component getComponentBefore(Container aContainer, Component aComponent) {
-          return sel();
-      }
-
-      public Component getFirstComponent(Container aContainer) {
-          return sel();
-      }
-
-      public Component getLastComponent(Container aContainer) {
-          return sel();
-      }
-
-      public Component getDefaultComponent(Container aContainer) {
-          return sel();
-      }
+  public final boolean requestFocusInWindow() {
+      Component sel = getSelectedComponent();
+      if (sel != null) return sel.requestFocusInWindow();
+      else return super.requestFocusInWindow();
   }
   
   
@@ -126,13 +106,23 @@ class DataSourceWindowTabbedPane extends JTabbedPane {
   public void addViewTab(DataSource dataSource, DataSourceView view) {
       ViewContainer container = new ViewContainer(new DataSourceCaption(dataSource), view);
       super.add(container);
-      boolean notGTK = !UIUtils.isGTKLookAndFeel();
-      setTitleAt(getComponentCount() - 1, view.getName() + ((view.isClosable() && notGTK) ? "  " : ""));  // NOI18N
-      ImageIcon tabIcon = notGTK ? new ImageIcon(view.getImage()) :
-          new ImageIcon(view.getImage()) {
-              public int getIconWidth() { return super.getIconWidth() + 12; }
-          };
-      super.setIconAt(getComponentCount() - 1, tabIcon);
+
+      final boolean closable = view.isClosable();
+      
+      if (UIUtils.isGTKLookAndFeel()) {
+          setTitleAt(getComponentCount() - 1, view.getName() + (closable ? "" : " "));  // NOI18N
+          super.setIconAt(getComponentCount() - 1, new ImageIcon(view.getImage()) {
+              public int getIconWidth() { return super.getIconWidth() + (closable ? 15 : 8); }
+          });
+      } else if (UIUtils.isNimbusLookAndFeel()) {
+          setTitleAt(getComponentCount() - 1, view.getName() + (closable ? "" : "  "));  // NOI18N
+          super.setIconAt(getComponentCount() - 1, new ImageIcon(view.getImage()) {
+              public int getIconWidth() { return super.getIconWidth() + (closable ? 10 : 0); }
+          });
+      } else {
+          setTitleAt(getComponentCount() - 1, view.getName() + (closable ? "  " : ""));  // NOI18N
+          super.setIconAt(getComponentCount() - 1, new ImageIcon(view.getImage()));
+      }
   }
   
   public void removeTabAt(int index) {
@@ -575,20 +565,28 @@ class DataSourceWindowTabbedPane extends JTabbedPane {
       private DataViewComponent viewComponent;
       
       public ViewContainer(DataSourceCaption caption, DataSourceView view) {
+          Color backgroundColor = UIUtils.getProfilerResultsBackground();
+
           this.caption = caption;
           this.view = view;
           this.viewComponent = view.getView();
           setLayout(new BorderLayout());
-          setBorder(BorderFactory.createMatteBorder(5, 5, 5, 5, Color.WHITE));
-          setBackground(Color.WHITE);
+          setBorder(BorderFactory.createMatteBorder(5, 5, 5, 5, backgroundColor));
+          setBackground(backgroundColor);
+          setFocusable(false);
           
           add(viewComponent, BorderLayout.CENTER);
           if (caption != null) {
               caption.setBorder(BorderFactory.createEmptyBorder(0, 0, 5, 0));
-              caption.setBackground(Color.WHITE);
+              caption.setBackground(backgroundColor);
               add(caption, BorderLayout.NORTH);
           }
       }
+
+      public final boolean requestFocusInWindow() {
+        if (getComponentCount() > 0) return getComponent(0).requestFocusInWindow();
+        else return super.requestFocusInWindow();
+      }
       
       public DataSourceCaption getCaption() { return caption; }
       
