@@ -26,8 +26,6 @@
 package com.sun.tools.visualvm.profiler;
 
 import com.sun.tools.visualvm.application.Application;
-import com.sun.tools.visualvm.application.jvm.Jvm;
-import com.sun.tools.visualvm.application.jvm.JvmFactory;
 import com.sun.tools.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
 import com.sun.tools.visualvm.core.datasupport.DataRemovedListener;
 import com.sun.tools.visualvm.core.datasupport.Stateful;
@@ -35,7 +33,7 @@ import com.sun.tools.visualvm.core.ui.DataSourceView;
 import com.sun.tools.visualvm.core.ui.DesktopUtils;
 import com.sun.tools.visualvm.core.ui.components.DataViewComponent;
 import java.awt.BorderLayout;
-import java.awt.Color;
+import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.Font;
 import java.awt.GridBagConstraints;
@@ -48,6 +46,7 @@ import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.net.URL;
 import java.text.MessageFormat;
+import javax.swing.AbstractButton;
 import javax.swing.BorderFactory;
 import javax.swing.ImageIcon;
 import javax.swing.JButton;
@@ -55,6 +54,7 @@ import javax.swing.JComponent;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
 import javax.swing.JToggleButton;
+import javax.swing.JToolBar;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
 import org.netbeans.lib.profiler.TargetAppRunner;
@@ -70,7 +70,6 @@ import org.netbeans.modules.profiler.utils.IDEUtils;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
-import org.openide.util.Utilities;
 import org.openide.util.WeakListeners;
 
 /**
@@ -208,6 +207,23 @@ class ApplicationProfilerView extends DataSourceView {
         
         private static JComponent getLiveResultsView() {
             JComponent view = LiveResultsWindow.getDefault();
+
+            Component[] components = view.getComponents();
+            if (components.length > 0 && components[0] instanceof JToolBar) {
+                JToolBar toolbar = (JToolBar)components[0];
+                toolbar.setOpaque(false);
+                components = toolbar.getComponents();
+                for (int i = 0; i < components.length; i++) {
+                    Component component = components[i];
+                    if (component instanceof AbstractButton) {
+                        ((AbstractButton)component).setOpaque(false);
+                        if (i == 5)
+                            ((AbstractButton)component).setText(NbBundle.getMessage(
+                                    ApplicationProfilerView.class, "LBL_Snapshot")); // NOI18N
+                    }
+                }
+            }
+
             view.setPreferredSize(new Dimension(1, 1));
             return view;
         }
@@ -654,8 +670,7 @@ class ApplicationProfilerView extends DataSourceView {
               stopButton.setPreferredSize(maxD);
               stopButton.setMinimumSize(maxD);
             
-              setOpaque(true);
-              setBackground(Color.WHITE);
+              setOpaque(false);
               
               setLayout(new BorderLayout());
               setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
