@@ -10,7 +10,7 @@ import org.openide.modules.ModuleInstall;
  * Manages a module's lifecycle. Remember that an installer is optional and
  * often not needed at all.
  */
-public class Installer extends ModuleInstall {
+class Installer extends ModuleInstall {
 
     public void restored() {
         ProfilerSupport.getInstance();
