@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -193,7 +193,7 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
         }
 
         initInstrMethodData();
-        instrumentClinit = threadInCallGraph;
+        boolean instrumentClinit = threadInCallGraph;
 
         if (!clazz.isLoaded()) {
             clazz.setLoaded(true);
@@ -275,7 +275,6 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
         }
 
         initInstrMethodData();
-        instrumentClinit = true;
 
         methodName = methodName.intern();
         methodSignature = methodSignature.intern();
