@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -64,8 +64,12 @@ import javax.swing.tree.TreePath;
 public final class UIUtils {
     //~ Static fields/initializers -----------------------------------------------------------------------------------------------
 
+    // Used to mark explicit expand/collapse on JTree which shouldn't be handled by automatic expander
+    public static final String PROP_EXPANSION_TRANSACTION = "expansion_transaction"; // NOI18N
+
     private static final Logger LOGGER = Logger.getLogger(UIUtils.class.getName());
     public static final float ALTERNATE_ROW_DARKER_FACTOR = 0.96f;
+    private static final int MAX_TREE_AUTOEXPAND_LINES = 50;
     private static boolean toolTipValuesInitialized = false;
     private static Color unfocusedSelBg;
     private static Color unfocusedSelFg;
@@ -316,12 +320,17 @@ public final class UIUtils {
      * @param path
      * @param maxChildToExpand
      */
-    public static void autoExpand(JTree tree, TreePath path, int maxChildToExpand, boolean dontExpandToLeafs) {
+    public static void autoExpand(JTree tree, TreePath path, int maxLines, int maxChildToExpand, boolean dontExpandToLeafs) {
         TreeModel model = tree.getModel();
         Object node = path.getLastPathComponent();
         TreePath newPath = path;
 
-        while (!model.isLeaf(node) && (model.getChildCount(node) > 0) && (model.getChildCount(node) <= maxChildToExpand)) {
+        int currentLines = 0;
+
+        while (currentLines++ < maxLines &&
+                !model.isLeaf(node) &&
+                (model.getChildCount(node) > 0) &&
+                (model.getChildCount(node) <= maxChildToExpand)) {
             for (int i = 0; i < model.getChildCount(node); i++) {
                 node = tree.getModel().getChild(node, i);
 
@@ -362,7 +371,7 @@ public final class UIUtils {
         }
 
         TreePath rootPath = new TreePath(root);
-        autoExpand(tree, rootPath, maxChildToExpand, false);
+        autoExpand(tree, rootPath, MAX_TREE_AUTOEXPAND_LINES, maxChildToExpand, false);
     }
 
     public static long[] copyArray(long[] array) {
@@ -450,41 +459,52 @@ public final class UIUtils {
      * and fixes using custom border for JDK 1.5 & XP LaF
      */
     public static void fixButtonUI(AbstractButton button) {
-        // JButton
-        if (button.getUI() instanceof com.sun.java.swing.plaf.windows.WindowsButtonUI) {
-            button.setUI(new com.sun.java.swing.plaf.windows.WindowsButtonUI() {
-                    protected BasicButtonListener createButtonListener(AbstractButton b) {
-                        return new BasicButtonListener(b); // Fix for  Issue 71546
-                    }
+        try { // Fix for Issue 175755 - WindowsButtonUI is private API, incompatible changes may occur
+            final int dashedRectGapX_Local = ((Integer)UIManager.get("Button.dashedRectGapX")).intValue(); // NOI18N
+            final int dashedRectGapY_Local = ((Integer)UIManager.get("Button.dashedRectGapY")).intValue(); // NOI18N
+            final int dashedRectGapWidth_Local = ((Integer)UIManager.get("Button.dashedRectGapWidth")).intValue(); // NOI18N
+            final int dashedRectGapHeight_Local = ((Integer)UIManager.get("Button.dashedRectGapHeight")).intValue(); // NOI18N
 
-                    protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect, Rectangle textRect,
-                                              Rectangle iconRect) {
-                        int width = b.getWidth();
-                        int height = b.getHeight();
-                        g.setColor(getFocusColor());
-                        javax.swing.plaf.basic.BasicGraphicsUtils.drawDashedRect(g, dashedRectGapX, dashedRectGapY,
-                                                                                 width - dashedRectGapWidth,
-                                                                                 height - dashedRectGapHeight);
-                    }
-                });
-        }
-        // JToggleButton
-        else if (button.getUI() instanceof com.sun.java.swing.plaf.windows.WindowsToggleButtonUI) {
-            button.setUI(new com.sun.java.swing.plaf.windows.WindowsToggleButtonUI() {
-                    protected BasicButtonListener createButtonListener(AbstractButton b) {
-                        return new BasicButtonListener(b); // Fix for  Issue 71546
-                    }
+            // JButton
+            if (button.getUI() instanceof com.sun.java.swing.plaf.windows.WindowsButtonUI) {
+                button.setUI(new com.sun.java.swing.plaf.windows.WindowsButtonUI() {
+                        protected BasicButtonListener createButtonListener(AbstractButton b) {
+                            return new BasicButtonListener(b); // Fix for  Issue 71546
+                        }
 
-                    protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect, Rectangle textRect,
-                                              Rectangle iconRect) {
-                        int width = b.getWidth();
-                        int height = b.getHeight();
-                        g.setColor(getFocusColor());
-                        javax.swing.plaf.basic.BasicGraphicsUtils.drawDashedRect(g, dashedRectGapX, dashedRectGapY,
-                                                                                 width - dashedRectGapWidth,
-                                                                                 height - dashedRectGapHeight);
-                    }
-                });
+                        protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect, Rectangle textRect,
+                                                  Rectangle iconRect) {
+                            int width = b.getWidth();
+                            int height = b.getHeight();
+                            g.setColor(getFocusColor());
+                            javax.swing.plaf.basic.BasicGraphicsUtils.drawDashedRect(g, dashedRectGapX_Local,
+                                                                                     dashedRectGapY_Local,
+                                                                                     width - dashedRectGapWidth_Local,
+                                                                                     height - dashedRectGapHeight_Local);
+                        }
+                    });
+            }
+            // JToggleButton
+            else if (button.getUI() instanceof com.sun.java.swing.plaf.windows.WindowsToggleButtonUI) {
+                button.setUI(new com.sun.java.swing.plaf.windows.WindowsToggleButtonUI() {
+                        protected BasicButtonListener createButtonListener(AbstractButton b) {
+                            return new BasicButtonListener(b); // Fix for  Issue 71546
+                        }
+
+                        protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect, Rectangle textRect,
+                                                  Rectangle iconRect) {
+                            int width = b.getWidth();
+                            int height = b.getHeight();
+                            g.setColor(getFocusColor());
+                            javax.swing.plaf.basic.BasicGraphicsUtils.drawDashedRect(g, dashedRectGapX_Local,
+                                                                                     dashedRectGapY_Local,
+                                                                                     width - dashedRectGapWidth_Local,
+                                                                                     height - dashedRectGapHeight_Local);
+                        }
+                    });
+            }
+        } catch (Throwable t) {
+            // Private API is used, just skip any incompatibility failure
         }
     }
 
@@ -526,7 +546,7 @@ public final class UIUtils {
         makeTreeAutoExpandable(tree, maxChildToExpand, false);
     }
 
-    public static void makeTreeAutoExpandable(JTree tree, final int maxChildToExpand, final boolean dontExpandToLeafs) {
+    public static void makeTreeAutoExpandable(final JTree tree, final int maxChildToExpand, final boolean dontExpandToLeafs) {
         tree.addTreeExpansionListener(new TreeExpansionListener() {
                 boolean internalChange = false;
 
@@ -534,7 +554,7 @@ public final class UIUtils {
                 }
 
                 public void treeExpanded(TreeExpansionEvent event) {
-                    if (internalChange) {
+                    if (internalChange || Boolean.TRUE.equals(tree.getClientProperty(PROP_EXPANSION_TRANSACTION))) { // NOI18N
                         return;
                     }
 
@@ -542,7 +562,7 @@ public final class UIUtils {
                     TreePath path = event.getPath();
                     JTree tree = (JTree) event.getSource();
                     internalChange = true;
-                    autoExpand(tree, path, maxChildToExpand, dontExpandToLeafs);
+                    autoExpand(tree, path, MAX_TREE_AUTOEXPAND_LINES, maxChildToExpand, dontExpandToLeafs);
                     internalChange = false;
                 }
             });
