@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -57,6 +57,8 @@ import java.util.ResourceBundle;
 import javax.swing.*;
 import javax.swing.event.PopupMenuEvent;
 import javax.swing.event.PopupMenuListener;
+import org.netbeans.lib.profiler.results.memory.ClassHistoryDataManager;
+import org.netbeans.lib.profiler.utils.StringUtils;
 
 
 /**
@@ -85,8 +87,8 @@ public class LiveLivenessResultsPanel extends LivenessResultsPanel implements Li
 
     protected TargetAppRunner runner;
 
-    //common actions handler
-    ActionsHandler handler;
+    private ClassHistoryActionsHandler historyActionsHandler;
+    private ClassHistoryDataManager classHistoryManager;
     private JMenuItem popupRemoveProfForClass;
     private JMenuItem popupRemoveProfForClassesBelow;
     private JMenuItem popupShowStacks;
@@ -98,16 +100,16 @@ public class LiveLivenessResultsPanel extends LivenessResultsPanel implements Li
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
-    public LiveLivenessResultsPanel(TargetAppRunner runner, MemoryResUserActionsHandler actionsHandler) {
-        this(runner, actionsHandler, null);
-    }
-
-    public LiveLivenessResultsPanel(TargetAppRunner runner, MemoryResUserActionsHandler actionsHandler, ActionsHandler handler) {
+    public LiveLivenessResultsPanel(TargetAppRunner runner,
+                                    MemoryResUserActionsHandler actionsHandler,
+                                    ClassHistoryActionsHandler historyActionsHandler,
+                                    ClassHistoryDataManager classHistoryManager) {
         super(actionsHandler);
         this.runner = runner;
         this.status = runner.getProfilerClient().getStatus();
+        this.historyActionsHandler = historyActionsHandler;
+        this.classHistoryManager = classHistoryManager;
         initColumnsData();
-        this.handler = handler;
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -175,9 +177,10 @@ public class LiveLivenessResultsPanel extends LivenessResultsPanel implements Li
             prepareResults();
         } else if (source == popupShowStacks) {
             actionsHandler.showStacksForClass(selectedClassId, getSortingColumn(), getSortingOrder());
-        } else if ((e.getSource() == startHisto) && (handler != null)) {
-            handler.performAction("history logging",
-                                  new Object[] { new Integer(selectedClassId), getClassName(selectedClassId), Boolean.TRUE }); // NOI18N
+        } else if (e.getSource() == startHisto) {
+            String selectedClassName = StringUtils.userFormClassName(
+                                                getClassName(selectedClassId));
+            historyActionsHandler.showClassHistory(selectedClassId, selectedClassName);
         }
     }
 
@@ -236,9 +239,14 @@ public class LiveLivenessResultsPanel extends LivenessResultsPanel implements Li
                 nTotalTracked += nTrackedLiveObjects[i];
             }
 
-            if (handler != null) {
-                handler.performAction("history update", new Object[] { nTrackedLiveObjects, nTotalAllocObjects }); // NOI18N
-            }
+            if (classHistoryManager.isTrackingClass())
+                classHistoryManager.processData(nTotalAllocObjects,
+                                                nTrackedLiveObjects,
+                                                trackedLiveObjectsSize);
+
+//            if (handler != null) {
+//                handler.performAction("history update", new Object[] { nTrackedLiveObjects, nTotalAllocObjects }); // NOI18N
+//            }
 
             initDataUponResultsFetch();
         }
@@ -372,24 +380,30 @@ public class LiveLivenessResultsPanel extends LivenessResultsPanel implements Li
             startHisto.addActionListener(this);
 
             popup.addPopupMenuListener(new PopupMenuListener() {
-                    public void popupMenuCanceled(PopupMenuEvent e) {
-                    }
+                public void popupMenuCanceled(PopupMenuEvent e) {
+                }
 
-                    public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
-                    }
+                public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
+                }
 
-                    public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
-                        SwingUtilities.invokeLater(new Runnable() {
-                                public void run() {
-                                    if (updateResultsPending) {
-                                        updateLiveResults();
-                                        updateResultsPending = false;
-                                    }
+                public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
+                    SwingUtilities.invokeLater(new Runnable() {
+                            public void run() {
+                                if (updateResultsPending) {
+                                    updateLiveResults();
+                                    updateResultsPending = false;
                                 }
-                            });
-                    }
-                });
+                            }
+                        });
+                }
+            });
         }
+        // Only show these items when target JVM is alive
+        boolean jvmAlive = status.targetAppRunning;
+        if (popupShowStacks != null) popupShowStacks.setEnabled(jvmAlive);
+        popupRemoveProfForClass.setEnabled(jvmAlive);
+        popupRemoveProfForClassesBelow.setEnabled(jvmAlive);
+        startHisto.setEnabled(jvmAlive);
 
         return popup;
     }
