@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -42,6 +42,7 @@ package org.netbeans.modules.profiler;
 
 import org.netbeans.lib.profiler.common.ProfilingSettings;
 import org.netbeans.lib.profiler.results.CCTNode;
+import org.netbeans.lib.profiler.results.ExportDataDumper;
 import org.netbeans.lib.profiler.results.ResultsSnapshot;
 import org.netbeans.lib.profiler.results.cpu.CPUResultsSnapshot;
 import org.netbeans.lib.profiler.results.cpu.PrestimeCPUCCTNode;
@@ -59,7 +60,6 @@ import org.netbeans.modules.profiler.utils.IDEUtils;
 import org.openide.actions.FindAction;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import org.openide.util.actions.SystemAction;
 import java.awt.*;
 import java.awt.event.ActionEvent;
@@ -88,7 +88,7 @@ import javax.swing.event.ChangeListener;
  */
 public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListener, ChangeListener,
                                                                      SnapshotResultsWindow.FindPerformer,
-                                                                     SaveViewAction.ViewProvider {
+                                                                     SaveViewAction.ViewProvider, ExportAction.ExportProvider {
     //~ Inner Classes ------------------------------------------------------------------------------------------------------------
 
     private final class CPUActionsHandler extends CPUResUserActionsHandler.Adapter {
@@ -309,22 +309,14 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
     private static final ImageIcon CLASSES_ICON = Utils.CLASS_ICON;
     private static final ImageIcon METHODS_ICON = Utils.METHODS_ICON;
     private static final ImageIcon PACKAGES_ICON = Utils.PACKAGE_ICON;
-    private static final ImageIcon CALL_TREE_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/callTreeTab.png") // NOI18N
-    );
-    private static final ImageIcon HOTSPOTS_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/hotspotsTab.png") // NOI18N
-    );
-    private static final ImageIcon COMBINED_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/combinedTab.png") // NOI18N
-    );
-    private static final ImageIcon INFO_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/infoTab.png") // NOI18N
-    );
-    private static final ImageIcon BACK_TRACES_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/backTracesTab.png") // NOI18N
-    );
-    private static final ImageIcon SUBTREE_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/subtree.png") // NOI18N
-    );
-    private static final ImageIcon SLAVE_DOWN_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/slaveDown.png") // NOI18N
-    );
-    private static final ImageIcon SLAVE_UP_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/slaveUp.png") // NOI18N
-    );
+    private static final ImageIcon CALL_TREE_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/callTreeTab.png", false);
+    private static final ImageIcon HOTSPOTS_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/hotspotsTab.png", false);
+    private static final ImageIcon COMBINED_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/combinedTab.png", false);
+    private static final ImageIcon INFO_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/infoTab.png", false);
+    private static final ImageIcon BACK_TRACES_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/backTracesTab.png", false);
+    private static final ImageIcon SUBTREE_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/subtree.png", false);
+    private static final ImageIcon SLAVE_DOWN_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/slaveDown.png", false);
+    private static final ImageIcon SLAVE_UP_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/slaveUp.png", false);
     private static final double SPLIT_HALF = 0.5d;
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
@@ -344,6 +336,7 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
     private JToggleButton slaveToggleButtonUp;
     private LoadedSnapshot loadedSnapshot;
     private ReverseCallGraphPanel backtraceView;
+    private SaveViewAction saveViewAction;
     private SnapshotFlatProfilePanel combinedFlat;
     private SnapshotFlatProfilePanel flatPanel;
     private SnapshotInfoPanel infoPanel;
@@ -469,8 +462,8 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
         toolBar.putClientProperty("JToolBar.isRollover", Boolean.TRUE); //NOI18N
         toolBar.setBorder(BorderFactory.createEmptyBorder(4, 0, 4, 0));
 
-        toolBar.add(new ExportSnapshotAction(loadedSnapshot));
-        toolBar.add(new SaveViewAction(this));
+        toolBar.add(new ExportAction(this, loadedSnapshot));
+        toolBar.add(saveViewAction = new SaveViewAction(this));
 
         toolBar.addSeparator();
 
@@ -505,10 +498,16 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
         threadIds = snapshot.getThreadIds();
 
         threadsCombo = new JComboBox(threadNames) {
+                public Dimension getMinimumSize() {
+                    Dimension d = super.getMinimumSize();
+                    d.width = 1;
+                    return d;
+                }
                 public Dimension getMaximumSize() {
-                    return new Dimension(getPreferredSize().width + 50, getPreferredSize().height);
+                    Dimension d = super.getPreferredSize();
+                    d.width += 50;
+                    return d;
                 }
-                ;
             };
         threadsCombo.getAccessibleContext().setAccessibleName(THREADS_COMBO_ACCESS_NAME);
         threadsCombo.getAccessibleContext().setAccessibleDescription(THREADS_COMBO_ACCESS_DESCR);
@@ -723,7 +722,7 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
 
     // --- Save Current View action support --------------------------------------
     public boolean hasView() {
-        return ((tabs.getSelectedComponent() != null) && tabs.getSelectedComponent() instanceof ScreenshotProvider);
+        return ((tabs.getSelectedComponent() != null) && (tabs.getSelectedComponent() instanceof ScreenshotProvider) && (tabs.getSelectedComponent()!=infoPanel));
     }
 
     // TODO use polymorphism instead of "if-else" dispatchig; curreant approach doesn't scale well
@@ -1078,6 +1077,7 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
 
         // update the toolbar if selected tab changed
         boolean findEnabled = tabs.getSelectedComponent() != infoPanel;
+        saveViewAction.setEnabled(findEnabled);
         findActionPresenter.setEnabled(findEnabled);
         findPreviousPresenter.setEnabled(findEnabled);
         findNextPresenter.setEnabled(findEnabled);
@@ -1111,4 +1111,26 @@ public final class CPUSnapshotPanel extends SnapshotPanel implements ActionListe
         combinedCCT.prepareResults();
         combinedFlat.prepareResults();
     }
+
+    public void exportData(int exportedFileType, ExportDataDumper eDD) {
+        if (tabs.getSelectedComponent() instanceof CCTDisplay) { // Call tree
+            cctPanel.exportData(exportedFileType,eDD,false, getTitle());
+        } else if (tabs.getSelectedComponent() instanceof SnapshotFlatProfilePanel) { // Hot Spots
+            flatPanel.exportData(exportedFileType,eDD,false, getTitle());
+        } else if (tabs.getSelectedComponent() instanceof SubtreeCallGraphPanel) { //Subtree
+            subtreeView.exportData(exportedFileType,eDD, getTitle());
+        } else if (tabs.getSelectedComponent() instanceof ReverseCallGraphPanel) { //Back Trace
+            backtraceView.exportData(exportedFileType,eDD, getTitle());
+        } else if (tabs.getSelectedComponent()==combined) { // Combined
+            combined.exportData(exportedFileType,eDD, getTitle());
+        }
+    }
+
+    public boolean hasLoadedSnapshot() {
+        return true;
+    }
+
+    public boolean hasExportableView() {
+        return ((tabs.getSelectedComponent() != null) && (tabs.getSelectedComponent()!=infoPanel));
+    }
 }
