@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -41,6 +41,7 @@
 package org.netbeans.modules.profiler;
 
 import org.netbeans.lib.profiler.common.Profiler;
+import org.netbeans.lib.profiler.results.ExportDataDumper;
 import org.netbeans.lib.profiler.results.ResultsSnapshot;
 import org.netbeans.lib.profiler.results.memory.AllocMemoryResultsSnapshot;
 import org.netbeans.lib.profiler.results.memory.LivenessMemoryResultsSnapshot;
@@ -55,7 +56,6 @@ import org.netbeans.modules.profiler.ui.FindDialog;
 import org.openide.actions.FindAction;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import org.openide.util.actions.SystemAction;
 import java.awt.*;
 import java.awt.event.ActionEvent;
@@ -79,7 +79,7 @@ import org.netbeans.modules.profiler.ui.Utils;
  * @author Ian Formanek
  */
 public class MemorySnapshotPanel extends SnapshotPanel implements ChangeListener, SnapshotResultsWindow.FindPerformer,
-                                                                  SaveViewAction.ViewProvider {
+                                                                  SaveViewAction.ViewProvider, ExportAction.ExportProvider {
     //~ Inner Classes ------------------------------------------------------------------------------------------------------------
 
     private class SnapshotActionsHandler implements MemoryResUserActionsHandler {
@@ -121,12 +121,9 @@ public class MemorySnapshotPanel extends SnapshotPanel implements ChangeListener
     private static final String FIND_ACTION_TOOLTIP = NbBundle.getMessage(MemorySnapshotPanel.class,
                                                                            "MemorySnapshotPanel_FindActionTooltip"); // NOI18N
                                                                                                                      // -----
-    private static final ImageIcon MEMORY_RESULTS_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/memoryResultsTab.png") // NOI18N
-    );
-    private static final ImageIcon INFO_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/infoTab.png") // NOI18N
-    );
-    private static final ImageIcon STACK_TRACES_TAB_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/resources/stackTracesTab.png") // NOI18N
-    );
+    private static final ImageIcon MEMORY_RESULTS_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/memoryResultsTab.png", false); //NOI18N
+    private static final ImageIcon INFO_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/infoTab.png", false); //NOI18N
+    private static final ImageIcon STACK_TRACES_TAB_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/resources/stackTracesTab.png", false); //NOI18N
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -195,7 +192,7 @@ public class MemorySnapshotPanel extends SnapshotPanel implements ChangeListener
         toolBar.putClientProperty("JToolBar.isRollover", Boolean.TRUE); //NOI18N
         toolBar.setBorder(BorderFactory.createEmptyBorder(4, 0, 4, 0));
 
-        toolBar.add(new ExportSnapshotAction(ls));
+        toolBar.add(new ExportAction(this,ls));
         toolBar.add(new SaveViewAction(this));
 
         toolBar.addSeparator();
@@ -314,10 +311,8 @@ public class MemorySnapshotPanel extends SnapshotPanel implements ChangeListener
             return true;
         } else if (tabs.getSelectedComponent() == reversePanel) {
             return reversePanel.hasView();
-        } else if (tabs.getSelectedComponent() == infoPanel) {
-            return true;
         }
-
+        
         return false;
     }
 
@@ -471,4 +466,29 @@ public class MemorySnapshotPanel extends SnapshotPanel implements ChangeListener
         findPreviousPresenter.setEnabled(findEnabled);
         findNextPresenter.setEnabled(findEnabled);
     }
+
+    public void exportData(int exportedFileType, ExportDataDumper eDD) {
+        if (tabs.getSelectedComponent() == memoryPanel) {
+            if (memoryPanel instanceof SnapshotAllocResultsPanel) {
+                ((SnapshotAllocResultsPanel)memoryPanel).exportData(exportedFileType, eDD, MEMORY_RESULTS_TAB_NAME);
+            } else if (memoryPanel instanceof SnapshotLivenessResultsPanel) {
+                ((SnapshotLivenessResultsPanel)memoryPanel).exportData(exportedFileType, eDD, MEMORY_RESULTS_TAB_NAME);
+            } 
+        } else if (tabs.getSelectedComponent() == reversePanel) {
+            reversePanel.exportData(exportedFileType, eDD, STACK_TRACES_TAB_NAME);
+        }
+    }
+
+    public boolean hasLoadedSnapshot() {
+        return !(snapshot==null);
+    }
+
+    public boolean hasExportableView() {
+        if (tabs.getSelectedComponent() == memoryPanel) {
+            return true;
+        } else if (tabs.getSelectedComponent() == reversePanel) {
+            return reversePanel.hasView();
+        }
+        return false;
+    }
 }
