@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -40,7 +40,7 @@
 
 package org.netbeans.modules.profiler.heapwalk.ui;
 
-import org.netbeans.lib.profiler.heap.*;
+
 import org.netbeans.lib.profiler.ui.UIConstants;
 import org.netbeans.lib.profiler.ui.UIUtils;
 import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
@@ -51,14 +51,11 @@ import org.netbeans.lib.profiler.ui.components.treetable.AbstractTreeTableModel;
 import org.netbeans.lib.profiler.ui.components.treetable.ExtendedTreeTableModel;
 import org.netbeans.lib.profiler.ui.components.treetable.JTreeTablePanel;
 import org.netbeans.lib.profiler.ui.components.treetable.TreeTableModel;
-import org.netbeans.modules.profiler.NetBeansProfiler;
 import org.netbeans.modules.profiler.heapwalk.FieldsBrowserController;
-import org.netbeans.modules.profiler.heapwalk.model.ClassNode;
 import org.netbeans.modules.profiler.heapwalk.model.HeapWalkerInstanceNode;
 import org.netbeans.modules.profiler.heapwalk.model.HeapWalkerNode;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Font;
@@ -90,8 +87,13 @@ import javax.swing.JScrollPane;
 import javax.swing.JTable;
 import javax.swing.KeyStroke;
 import javax.swing.ListSelectionModel;
+import javax.swing.SwingUtilities;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumnModel;
+import org.netbeans.lib.profiler.heap.Instance;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker.StateEvent;
+import org.openide.util.RequestProcessor;
 
 
 /**
@@ -120,28 +122,33 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
     private class FieldsListTableMouseListener extends MouseAdapter {
         //~ Methods --------------------------------------------------------------------------------------------------------------
 
-        public void mouseClicked(MouseEvent e) {
-            int row = fieldsListTable.rowAtPoint(e.getPoint());
-
-            if (row != -1) {
-                HeapWalkerNode node = (HeapWalkerNode) fieldsListTable.getTree().getPathForRow(row).getLastPathComponent();
-
-                if ((e.getModifiers() == InputEvent.BUTTON1_MASK) && (e.getClickCount() == 2)) {
-                    if (node instanceof HeapWalkerInstanceNode) {
-                        performDefaultAction();
-                    }
-                } else if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                    showPopupMenu(row, e.getX(), e.getY());
-                }
-            }
+        private void updateSelection(int row) {
+            fieldsListTable.requestFocusInWindow();
+            if (row != -1) fieldsListTable.setRowSelectionInterval(row, row);
+            else fieldsListTable.clearSelection();
         }
 
-        public void mousePressed(MouseEvent e) {
-            int row = fieldsListTable.rowAtPoint(e.getPoint());
+        public void mousePressed(final MouseEvent e) {
+            final int row = fieldsListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) showPopupMenu(row, e.getX(), e.getY());
+        }
 
-            if (row != -1) {
-                if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                    fieldsListTable.setRowSelectionInterval(row, row);
+        public void mouseReleased(MouseEvent e) {
+            int row = fieldsListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) showPopupMenu(row, e.getX(), e.getY());
+        }
+
+        public void mouseClicked(MouseEvent e) {
+            if (SwingUtilities.isLeftMouseButton(e) && e.getClickCount() == 2) {
+                int row = fieldsListTable.rowAtPoint(e.getPoint());
+                if (e.getX() >= fieldsListTable.getTree().getRowBounds(row).x -
+                                fieldsListTable.getTreeCellOffsetX() && row != -1) {
+                    HeapWalkerNode node = (HeapWalkerNode) fieldsListTable.getTree().
+                            getPathForRow(row).getLastPathComponent();
+                    if (node instanceof HeapWalkerInstanceNode)
+                            performDefaultAction();
                 }
             }
         }
@@ -198,6 +205,10 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
                     return fieldNode.getType();
                 case 3:
                     return fieldNode.getValue();
+                case 4:
+                    return fieldNode.getSize();
+                case 5:
+                    return fieldNode.getRetainedSize();
                 default:
                     return null;
             }
@@ -246,13 +257,21 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
                                                                         "FieldsBrowserControllerUI_ValueColumnName"); // NOI18N
     private static final String VALUE_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
                                                                          "FieldsBrowserControllerUI_ValueColumnDescr"); // NOI18N
-                                                                                                                        // -----
-    private static ImageIcon ICON_FIELDS = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/heapwalk/ui/resources/data.png")); // NOI18N
+    private static final String SIZE_COLUMN_NAME = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+                                                                        "FieldsBrowserControllerUI_SizeColumnName"); // NOI18N
+    private static final String SIZE_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+                                                                         "FieldsBrowserControllerUI_SizeColumnDescr"); // NOI18N
+    private static final String RETAINED_SIZE_COLUMN_NAME = NbBundle.getMessage(InstancesListControllerUI.class,
+                                                                                "InstancesListControllerUI_RetainedSizeColumnName"); // NOI18N
+    private static final String RETAINED_SIZE_COLUMN_DESCR = NbBundle.getMessage(InstancesListControllerUI.class,
+                                                                                 "InstancesListControllerUI_RetainedSizeColumnDescr"); // NOI18N
+    // -----
+    private static ImageIcon ICON_FIELDS = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/heapwalk/ui/resources/data.png", false); // NOI18N
 
     // --- UI definition ---------------------------------------------------------
     private static final String DATA = "Data"; // NOI18N
     private static final String NO_DATA = "No data"; // NOI18N
-    private static final int columnCount = 4;
+    private int columnCount;
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -279,6 +298,8 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
     private boolean sortingOrder = true;
     private int sortingColumn = 0;
 
+    private boolean retainedSizeSupported;
+
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     // --- Constructors ----------------------------------------------------------
@@ -289,6 +310,11 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
 
         this.fieldsBrowserController = fieldsBrowserController;
 
+        retainedSizeSupported = fieldsBrowserController.getInstancesControllerHandler().
+                                getHeapFragmentWalker().getRetainedSizesStatus() !=
+                                HeapFragmentWalker.RETAINED_SIZES_UNSUPPORTED;
+        columnCount = retainedSizeSupported ? 6 : 5;
+
         realFieldsListTableModel = new FieldsListTreeTableModel();
         fieldsListTableModel = new ExtendedTreeTableModel(realFieldsListTableModel);
 
@@ -303,6 +329,26 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         initColumnsData();
         initData();
         initComponents();
+
+        fieldsBrowserController.getInstancesControllerHandler().
+            getHeapFragmentWalker().addStateListener(
+                new HeapFragmentWalker.StateListener() {
+                    public void stateChanged(StateEvent e) {
+                        if (e.getRetainedSizesStatus() == HeapFragmentWalker.
+                            RETAINED_SIZES_COMPUTED && e.isMasterChange()) {
+                                SwingUtilities.invokeLater(new Runnable() {
+                                    public void run() {
+                                        fieldsListTableModel.
+                                                setRealColumnVisibility(5, true);
+                                        fieldsListTable.createDefaultColumnsFromModel();
+                                        fieldsListTable.updateTreeTableHeader();
+                                        setColumnsData();
+                                    }
+                                });
+                        }
+                    }
+                }
+            );
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -384,20 +430,47 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         }
     }
 
-    private void addMenuItemListener(JCheckBoxMenuItem menuItem) {
+    private void addMenuItemListener(final JCheckBoxMenuItem menuItem) {
+        final boolean[] internalChange = new boolean[1];
         menuItem.addActionListener(new java.awt.event.ActionListener() {
-                public void actionPerformed(java.awt.event.ActionEvent e) {
-                    int column = Integer.parseInt(e.getActionCommand());
-                    fieldsListTableModel.setRealColumnVisibility(column, !fieldsListTableModel.isRealColumnVisible(column));
+            public void actionPerformed(java.awt.event.ActionEvent e) {
+                if (internalChange[0]) return;
+                final int column = Integer.parseInt(e.getActionCommand());
+                if (column == 5 && !fieldsListTableModel.isRealColumnVisible(column)) {
+                    RequestProcessor.getDefault().post(new Runnable() {
+                        public void run() {
+                            final int retainedSizesState = fieldsBrowserController.getInstancesControllerHandler().
+                                    getHeapFragmentWalker().computeRetainedSizes(false);
+                            SwingUtilities.invokeLater(new Runnable() {
+                                public void run() {
+                                    if (retainedSizesState != HeapFragmentWalker.RETAINED_SIZES_COMPUTED) {
+                                        internalChange[0] = true;
+                                        menuItem.setSelected(!menuItem.isSelected());
+                                        internalChange[0] = false;
+                                    } else {
+                                        fieldsListTableModel.setRealColumnVisibility(column,
+                                                !fieldsListTableModel.isRealColumnVisible(column));
+                                        fieldsListTable.createDefaultColumnsFromModel();
+                                        fieldsListTable.updateTreeTableHeader();
+                                        setColumnsData();
+                                    }
+                                }
+                            });
+                        }
+                    });
+                } else {
+                    fieldsListTableModel.setRealColumnVisibility(column,
+                            !fieldsListTableModel.isRealColumnVisible(column));
                     fieldsListTable.createDefaultColumnsFromModel();
                     fieldsListTable.updateTreeTableHeader();
                     setColumnsData();
                 }
-            });
+            }
+        });
     }
 
     private JButton createHeaderPopupCornerButton(final JPopupMenu headerPopup) {
-        final JButton cornerButton = new JButton(new ImageIcon(ImageUtilities.loadImage("org/netbeans/lib/profiler/ui/resources/hideColumn.png"))); // NOI18N
+        final JButton cornerButton = new JButton(ImageUtilities.loadImageIcon("org/netbeans/lib/profiler/ui/resources/hideColumn.png", false)); // NOI18N
         cornerButton.setToolTipText(SHOW_HIDE_COLUMNS_STRING);
         cornerButton.setDefaultCapable(false);
 
@@ -518,6 +591,14 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         columnNames[3] = VALUE_COLUMN_NAME;
         columnToolTips[3] = VALUE_COLUMN_DESCR;
 
+        columnNames[4] = SIZE_COLUMN_NAME;
+        columnToolTips[4] = SIZE_COLUMN_DESCR;
+
+        if (retainedSizeSupported) {
+            columnNames[5] = RETAINED_SIZE_COLUMN_NAME;
+            columnToolTips[5] = RETAINED_SIZE_COLUMN_DESCR;
+        }
+
         int unitWidth = getFontMetrics(getFont()).charWidth('W'); // NOI18N // initial width of data columns
 
         FieldTreeCellRenderer treeCellRenderer = new FieldTreeCellRenderer();
@@ -538,6 +619,14 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
 
         columnWidths[3 - 1] = unitWidth * 14;
         columnRenderers[3] = dataCellRenderer;
+
+        columnWidths[4 - 1] = unitWidth * 7;
+        columnRenderers[4] = dataCellRenderer;
+
+        if (retainedSizeSupported) {
+            columnWidths[5 - 1] = unitWidth * 7;
+            columnRenderers[5] = dataCellRenderer;
+        }
     }
 
     private void initComponents() {
@@ -546,6 +635,12 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         treeCellRenderer.setOpenIcon(null);
 
         fieldsListTableModel.setRealColumnVisibility(2, false);
+        fieldsListTableModel.setRealColumnVisibility(4, false);
+
+        if (retainedSizeSupported)
+            fieldsListTableModel.setRealColumnVisibility(5, fieldsBrowserController.
+                getInstancesControllerHandler().getHeapFragmentWalker().getRetainedSizesStatus()
+                                          == HeapFragmentWalker.RETAINED_SIZES_COMPUTED);
 
         fieldsListTable = new JTreeTable(fieldsListTableModel) {
                 public void doLayout() {
@@ -578,15 +673,17 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         fieldsListTable.setShowVerticalLines(UIConstants.SHOW_TABLE_VERTICAL_GRID);
         fieldsListTable.setRowMargin(UIConstants.TABLE_ROW_MARGIN);
         fieldsListTable.setRowHeight(UIUtils.getDefaultRowHeight() + 2);
+        fieldsListTable.getTree().setLargeModel(true);
+        fieldsListTable.getTree().setToggleClickCount(0);
         fieldsListTable.getColumnModel().getColumn(0).setMinWidth(150);
         fieldsListTable.getInputMap(JTable.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT)
                        .put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), "DEFAULT_ACTION"); // NOI18N
-        fieldsListTable.getActionMap().put("DEFAULT_ACTION",
+        fieldsListTable.getActionMap().put("DEFAULT_ACTION", // NOI18N
                                            new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     performDefaultAction();
                 }
-            }); // NOI18N
+            });
 
         // Disable traversing table cells using TAB and Shift+TAB
         Set keys = new HashSet(fieldsListTable.getFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS));
@@ -618,13 +715,13 @@ public class FieldsBrowserControllerUI extends JTitledPanel {
         String hintText = (fieldsBrowserController.getRootMode() == FieldsBrowserController.ROOT_INSTANCE)
                           ? MessageFormat.format(NO_INSTANCE_SELECTED_MSG,
                                                  new Object[] {
-                                                     "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png'>"
+                                                     "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png'>" // NOI18N
                                                  })
-                          : // NOI18N
+                          :
         MessageFormat.format(NO_CLASS_SELECTED_MSG,
                              new Object[] {
-                                 "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/classes.png'>"
-                             }); // NOI18N
+                                 "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/classes.png'>" // NOI18N
+                             });
         hintArea.setText(hintText);
         noDataPanel.add(hintArea, BorderLayout.CENTER);
 
