@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -40,7 +40,7 @@
 
 package org.netbeans.modules.profiler.heapwalk.ui;
 
-import org.netbeans.lib.profiler.heap.*;
+
 import org.netbeans.lib.profiler.ui.UIConstants;
 import org.netbeans.lib.profiler.ui.UIUtils;
 import org.netbeans.lib.profiler.ui.components.HTMLTextArea;
@@ -59,7 +59,6 @@ import org.netbeans.modules.profiler.heapwalk.model.HeapWalkerNode;
 import org.netbeans.modules.profiler.heapwalk.model.InstanceNode;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Font;
@@ -89,11 +88,19 @@ import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
 import javax.swing.JScrollPane;
 import javax.swing.JTable;
+import javax.swing.JTree;
 import javax.swing.KeyStroke;
 import javax.swing.ListSelectionModel;
+import javax.swing.SwingUtilities;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumnModel;
+import javax.swing.tree.TreePath;
+import org.netbeans.lib.profiler.heap.Instance;
+import org.netbeans.lib.profiler.results.CCTNode;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker.StateEvent;
 import org.netbeans.modules.profiler.heapwalk.model.HeapWalkerNodeFactory;
+import org.openide.util.RequestProcessor;
 
 
 /**
@@ -123,28 +130,33 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
     private class FieldsListTableMouseListener extends MouseAdapter {
         //~ Methods --------------------------------------------------------------------------------------------------------------
 
-        public void mouseClicked(MouseEvent e) {
-            int row = fieldsListTable.rowAtPoint(e.getPoint());
-
-            if (row != -1) {
-                HeapWalkerNode node = (HeapWalkerNode) fieldsListTable.getTree().getPathForRow(row).getLastPathComponent();
-
-                if ((e.getModifiers() == InputEvent.BUTTON1_MASK) && (e.getClickCount() == 2)) {
-                    if (node instanceof HeapWalkerInstanceNode) {
-                        performDefaultAction();
-                    }
-                } else if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                    showPopupMenu(row, e.getX(), e.getY());
-                }
-            }
+        private void updateSelection(int row) {
+            fieldsListTable.requestFocusInWindow();
+            if (row != -1) fieldsListTable.setRowSelectionInterval(row, row);
+            else fieldsListTable.clearSelection();
         }
 
-        public void mousePressed(MouseEvent e) {
-            int row = fieldsListTable.rowAtPoint(e.getPoint());
+        public void mousePressed(final MouseEvent e) {
+            final int row = fieldsListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) showPopupMenu(row, e.getX(), e.getY());
+        }
 
-            if (row != -1) {
-                if (e.getModifiers() == InputEvent.BUTTON3_MASK) {
-                    fieldsListTable.setRowSelectionInterval(row, row);
+        public void mouseReleased(MouseEvent e) {
+            int row = fieldsListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) showPopupMenu(row, e.getX(), e.getY());
+        }
+
+        public void mouseClicked(MouseEvent e) {
+            if (SwingUtilities.isLeftMouseButton(e) && e.getClickCount() == 2) {
+                int row = fieldsListTable.rowAtPoint(e.getPoint());
+                if (e.getX() >= fieldsListTable.getTree().getRowBounds(row).x -
+                                fieldsListTable.getTreeCellOffsetX() && row != -1) {
+                    HeapWalkerNode node = (HeapWalkerNode) fieldsListTable.getTree().
+                            getPathForRow(row).getLastPathComponent();
+                    if (node instanceof HeapWalkerInstanceNode)
+                            performDefaultAction();
                 }
             }
         }
@@ -200,6 +212,10 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
                     return fieldNode.getType();
                 case 3:
                     return fieldNode.getValue();
+                case 4:
+                    return fieldNode.getSize();
+                case 5:
+                    return fieldNode.getRetainedSize();
                 default:
                     return null;
             }
@@ -226,36 +242,44 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
                                                                              "ReferencesBrowserControllerUI_GoToSourceItemText"); // NOI18N
     private static final String SHOW_HIDE_COLUMNS_STRING = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                                "ReferencesBrowserControllerUI_ShowHideColumnsString"); // NOI18N
-    private static final String FIELD_COLUMN_NAME = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String FIELD_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                         "ReferencesBrowserControllerUI_FieldColumnName"); // NOI18N
-    private static final String FIELD_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String FIELD_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                          "ReferencesBrowserControllerUI_FieldColumnDescr"); // NOI18N
-    private static final String TYPE_COLUMN_NAME = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String TYPE_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                        "ReferencesBrowserControllerUI_TypeColumnName"); // NOI18N
-    private static final String TYPE_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String TYPE_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                         "ReferencesBrowserControllerUI_TypeColumnDescr"); // NOI18N
-    private static final String FULL_TYPE_COLUMN_NAME = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String FULL_TYPE_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                             "ReferencesBrowserControllerUI_FullTypeColumnName"); // NOI18N
-    private static final String FULL_TYPE_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String FULL_TYPE_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                              "ReferencesBrowserControllerUI_FullTypeColumnDescr"); // NOI18N
-    private static final String VALUE_COLUMN_NAME = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String VALUE_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                         "ReferencesBrowserControllerUI_ValueColumnName"); // NOI18N
-    private static final String VALUE_COLUMN_DESCR = NbBundle.getMessage(FieldsBrowserControllerUI.class,
+    private static final String VALUE_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
                                                                          "ReferencesBrowserControllerUI_ValueColumnDescr"); // NOI18N
-                                                                                                                            // -----
-    private static ImageIcon ICON_FIELDS = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/heapwalk/ui/resources/incomingRef.png")); // NOI18N
+    private static final String SIZE_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
+                                                                       "ReferencesBrowserControllerUI_SizeColumnName"); // NOI18N
+    private static final String SIZE_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
+                                                                        "ReferencesBrowserControllerUI_SizeColumnDescr"); // NOI18N
+    private static final String RETAINED_SIZE_COLUMN_NAME = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
+                                                                                "ReferencesBrowserControllerUI_RetainedSizeColumnName"); // NOI18N
+    private static final String RETAINED_SIZE_COLUMN_DESCR = NbBundle.getMessage(ReferencesBrowserControllerUI.class,
+                                                                                 "ReferencesBrowserControllerUI_RetainedSizeColumnDescr"); // NOI18N
+    // -----
+    private static ImageIcon ICON_FIELDS = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/heapwalk/ui/resources/incomingRef.png", false); // NOI18N
 
     // --- UI definition ---------------------------------------------------------
     private static final String DATA = "Data"; // NOI18N
     private static final String NO_DATA = "No data"; // NOI18N
-    private static final int columnCount = 4;
+    private int columnCount;
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
     private CardLayout contents;
     private FieldTreeCellRenderer treeCellRenderer = new FieldTreeCellRenderer();
-    private FieldsListTreeTableModel realFieldsListTableModel = new FieldsListTreeTableModel();
-    private ExtendedTreeTableModel fieldsListTableModel = new ExtendedTreeTableModel(realFieldsListTableModel);
+    private FieldsListTreeTableModel realFieldsListTableModel;
+    private ExtendedTreeTableModel fieldsListTableModel;
 //    private JMenuItem showClassItem;
     private JMenuItem showGcRootItem;
     private JMenuItem showInstanceItem;
@@ -276,6 +300,9 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
     private boolean sortingOrder = true;
     private int sortingColumn = 0;
 
+    private boolean retainedSizeSupported;
+
+
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     // --- Constructors ----------------------------------------------------------
@@ -284,6 +311,14 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
         this.referencesBrowserController = referencesBrowserController;
 
+        retainedSizeSupported = referencesBrowserController.getReferencesControllerHandler().
+                                getHeapFragmentWalker().getRetainedSizesStatus() !=
+                                HeapFragmentWalker.RETAINED_SIZES_UNSUPPORTED;
+        columnCount = retainedSizeSupported ? 6 : 5;
+
+        realFieldsListTableModel = new FieldsListTreeTableModel();
+        fieldsListTableModel = new ExtendedTreeTableModel(realFieldsListTableModel);
+
         addHierarchyListener(new HierarchyListener() {
                 public void hierarchyChanged(HierarchyEvent e) {
                     if (((e.getChangeFlags() & HierarchyEvent.SHOWING_CHANGED) != 0) && isShowing() && needsUpdate) {
@@ -295,6 +330,27 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         initColumnsData();
         initData();
         initComponents();
+
+        referencesBrowserController.getReferencesControllerHandler().
+            getHeapFragmentWalker().addStateListener(
+                new HeapFragmentWalker.StateListener() {
+                    public void stateChanged(StateEvent e) {
+                        if (e.getRetainedSizesStatus() == HeapFragmentWalker.
+                            RETAINED_SIZES_COMPUTED && e.isMasterChange()) {
+                                SwingUtilities.invokeLater(new Runnable() {
+                                    public void run() {
+                                        fieldsListTableModel.
+                                                setRealColumnVisibility(5, true);
+                                        fieldsListTable.createDefaultColumnsFromModel();
+                                        fieldsListTable.updateTreeTableHeader();
+                                        setColumnsData();
+                                    }
+                                });
+                        }
+                    }
+                }
+            );
+
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -307,8 +363,33 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         }
     }
 
+    private static final int MAX_STEP = 10;
+
     public void selectNode(HeapWalkerNode node) {
-        fieldsListTable.selectNode(node, true);
+        CCTNode[] pathArr = fieldsListTable.getPathToRoot(node);
+//        System.err.println(">>> About to open path size: " + pathArr.length);
+
+        selectPath(pathArr, Math.min(pathArr.length, MAX_STEP));
+
+//        fieldsListTable.selectNode(node, true);
+    }
+
+    private void selectPath(final CCTNode[] path, final int length) {
+        if (length >= path.length) {
+            fieldsListTable.getTree().setSelectionPath(new TreePath(path));
+        } else {
+            Object[] shortPath = new Object[length];
+            System.arraycopy(path, 0, shortPath, 0, length);
+            final TreePath p = new TreePath(shortPath);
+            SwingUtilities.invokeLater(new Runnable() {
+                public void run() {
+//                    System.err.println(">>> Selecting length " + length);
+                    fieldsListTable.getTree().setSelectionPath(p);
+                    fieldsListTable.scrollRectToVisible(fieldsListTable.getCellRect(fieldsListTable.getSelectedRow(), 0, true));
+                    selectPath(path, length + MAX_STEP);
+                }
+            });
+        }
     }
 
     // --- Public interface ------------------------------------------------------
@@ -375,20 +456,47 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         }
     }
 
-    private void addMenuItemListener(JCheckBoxMenuItem menuItem) {
+    private void addMenuItemListener(final JCheckBoxMenuItem menuItem) {
+        final boolean[] internalChange = new boolean[1];
         menuItem.addActionListener(new java.awt.event.ActionListener() {
-                public void actionPerformed(java.awt.event.ActionEvent e) {
-                    int column = Integer.parseInt(e.getActionCommand());
-                    fieldsListTableModel.setRealColumnVisibility(column, !fieldsListTableModel.isRealColumnVisible(column));
+            public void actionPerformed(java.awt.event.ActionEvent e) {
+                if (internalChange[0]) return;
+                final int column = Integer.parseInt(e.getActionCommand());
+                if (column == 5 && !fieldsListTableModel.isRealColumnVisible(column)) {
+                    RequestProcessor.getDefault().post(new Runnable() {
+                        public void run() {
+                            final int retainedSizesState = referencesBrowserController.getReferencesControllerHandler().
+                                    getHeapFragmentWalker().computeRetainedSizes(false);
+                            SwingUtilities.invokeLater(new Runnable() {
+                                public void run() {
+                                    if (retainedSizesState != HeapFragmentWalker.RETAINED_SIZES_COMPUTED) {
+                                        internalChange[0] = true;
+                                        menuItem.setSelected(!menuItem.isSelected());
+                                        internalChange[0] = false;
+                                    } else {
+                                        fieldsListTableModel.setRealColumnVisibility(column,
+                                                !fieldsListTableModel.isRealColumnVisible(column));
+                                        fieldsListTable.createDefaultColumnsFromModel();
+                                        fieldsListTable.updateTreeTableHeader();
+                                        setColumnsData();
+                                    }
+                                }
+                            });
+                        }
+                    });
+                } else {
+                    fieldsListTableModel.setRealColumnVisibility(column,
+                            !fieldsListTableModel.isRealColumnVisible(column));
                     fieldsListTable.createDefaultColumnsFromModel();
                     fieldsListTable.updateTreeTableHeader();
                     setColumnsData();
                 }
-            });
+            }
+        });
     }
 
     private JButton createHeaderPopupCornerButton(final JPopupMenu headerPopup) {
-        final JButton cornerButton = new JButton(new ImageIcon(ImageUtilities.loadImage("org/netbeans/lib/profiler/ui/resources/hideColumn.png"))); // NOI18N
+        final JButton cornerButton = new JButton(ImageUtilities.loadImageIcon("org/netbeans/lib/profiler/ui/resources/hideColumn.png", false)); // NOI18N
         cornerButton.setToolTipText(SHOW_HIDE_COLUMNS_STRING);
         cornerButton.setDefaultCapable(false);
 
@@ -526,6 +634,14 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         columnNames[3] = VALUE_COLUMN_NAME;
         columnToolTips[3] = VALUE_COLUMN_DESCR;
 
+        columnNames[4] = SIZE_COLUMN_NAME;
+        columnToolTips[4] = SIZE_COLUMN_DESCR;
+
+        if (retainedSizeSupported) {
+            columnNames[5] = RETAINED_SIZE_COLUMN_NAME;
+            columnToolTips[5] = RETAINED_SIZE_COLUMN_DESCR;
+        }
+
         int unitWidth = getFontMetrics(getFont()).charWidth('W'); // NOI18N // initial width of data columns
 
         FieldTreeCellRenderer treeCellRenderer = new FieldTreeCellRenderer();
@@ -546,6 +662,14 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
         columnWidths[3 - 1] = unitWidth * 14;
         columnRenderers[3] = dataCellRenderer;
+
+        columnWidths[4 - 1] = unitWidth * 7;
+        columnRenderers[4] = dataCellRenderer;
+
+        if (retainedSizeSupported) {
+            columnWidths[5 - 1] = unitWidth * 7;
+            columnRenderers[5] = dataCellRenderer;
+        }
     }
 
     private void initComponents() {
@@ -554,6 +678,12 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         treeCellRenderer.setOpenIcon(null);
 
         fieldsListTableModel.setRealColumnVisibility(2, false);
+        fieldsListTableModel.setRealColumnVisibility(4, false);
+
+        if (retainedSizeSupported)
+            fieldsListTableModel.setRealColumnVisibility(5, referencesBrowserController.
+                getReferencesControllerHandler().getHeapFragmentWalker().getRetainedSizesStatus()
+                                          == HeapFragmentWalker.RETAINED_SIZES_COMPUTED);
 
         fieldsListTable = new JTreeTable(fieldsListTableModel) {
                 public void doLayout() {
@@ -576,7 +706,6 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
                     super.doLayout();
                 }
-                ;
             };
         fieldsListTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
         fieldsListTable.setGridColor(UIConstants.TABLE_VERTICAL_GRID_COLOR);
@@ -586,15 +715,17 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         fieldsListTable.setShowVerticalLines(UIConstants.SHOW_TABLE_VERTICAL_GRID);
         fieldsListTable.setRowMargin(UIConstants.TABLE_ROW_MARGIN);
         fieldsListTable.setRowHeight(UIUtils.getDefaultRowHeight() + 2);
+        fieldsListTable.getTree().setLargeModel(true);
+        fieldsListTable.getTree().setToggleClickCount(0);
         fieldsListTable.getColumnModel().getColumn(0).setMinWidth(150);
         fieldsListTable.getInputMap(JTable.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT)
                        .put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0), "DEFAULT_ACTION"); // NOI18N
-        fieldsListTable.getActionMap().put("DEFAULT_ACTION",
+        fieldsListTable.getActionMap().put("DEFAULT_ACTION", // NOI18N
                                            new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     performDefaultAction();
                 }
-            }); // NOI18N
+            });
 
         // Disable traversing table cells using TAB and Shift+TAB
         Set keys = new HashSet(fieldsListTable.getFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS));
@@ -625,8 +756,8 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
         String hintText = MessageFormat.format(NO_INSTANCE_SELECTED_MSG,
                                                new Object[] {
-                                                   "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png'>"
-                                               }); // NOI18N
+                                                   "<img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png'>" // NOI18N
+                                               });
         hintArea.setText(hintText);
         noDataPanel.add(hintArea, BorderLayout.CENTER);
 
@@ -641,7 +772,7 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
     // --- Private implementation ------------------------------------------------
     private void initData() {
-        fieldsListTableModel.setRoot(referencesBrowserController.getFilteredSortedFields(filterValue, sortingColumn, sortingOrder));
+        fieldsListTableModel.setRoot(referencesBrowserController.getFilteredSortedReferences(filterValue, sortingColumn, sortingOrder));
         refreshView();
     }
 
@@ -698,8 +829,8 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
         }
 
 //        showClassItem.setEnabled(node instanceof HeapWalkerInstanceNode || node instanceof ClassNode);
-        showGcRootItem.setEnabled(node instanceof HeapWalkerInstanceNode && node.currentlyHasChildren() &&
-                (node.getNChildren() != 1 || !HeapWalkerNodeFactory.isMessageNode(node.getChild(0)))); // #124306
+        showGcRootItem.setEnabled(node instanceof HeapWalkerInstanceNode && (!node.currentlyHasChildren() ||
+                (node.getNChildren() != 1 || !HeapWalkerNodeFactory.isMessageNode(node.getChild(0))))); // #124306
 
         if ((x == -1) || (y == -1)) {
             Rectangle rowBounds = fieldsListTable.getCellRect(row, 0, true);
