@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -134,6 +134,7 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
                                                                                    "StpManageFilterSetsTooltip"); // NOI18N
     private static final String STP_USEPPS_TOOLTIP = NbBundle.getMessage(CPUSettingsBasicPanel.class, "StpUsePpsTooltip"); // NOI18N
     private static final String STP_SHOWPPS_TOOLTIP = NbBundle.getMessage(CPUSettingsBasicPanel.class, "StpShowPpsTooltip"); // NOI18N
+    private static final String SHOW_FILTER_CAPTION = NbBundle.getMessage(CPUSettingsBasicPanel.class, "CPUSettingsBasicPanel_ShowFilterCaption"); // NOI18N
                                                                                                                              // -----
 
     // --- Instance variables declaration ----------------------------------------
@@ -262,10 +263,7 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
                                                                                             //      UIManager.setLookAndFeel("plaf.metal.MetalLookAndFeel"); //NOI18N
                                                                                             //      UIManager.setLookAndFeel("com.sun.java.swing.plaf.motif.MotifLookAndFeel"); //NOI18N
                                                                                             //      UIManager.setLookAndFeel("com.sun.java.swing.plaf.gtk.GTKLookAndFeel"); //NOI18N
-        } catch (Exception e) {
-        }
-
-        ;
+        } catch (Exception e) {}
 
         JFrame frame = new JFrame("Tester Frame"); //NOI18N
         JPanel contents = new CPUSettingsBasicPanel();
@@ -281,7 +279,7 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
     }
 
     public void popupMenuWillBecomeInvisible(final PopupMenuEvent e) {
-        if ((!filterComboBoxPopupCancelled) && (filterCombo.getSelectedItem().equals(quickFilter))) {
+        if (!filterComboBoxPopupCancelled && quickFilter != null && quickFilter.equals(filterCombo.getSelectedItem())) {
             filterCombo.removePopupMenuListener(this);
             filterCombo.hidePopup();
             filterCombo.addPopupMenuListener(this);
@@ -757,8 +755,8 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
             }
         };
 
-        final DialogDescriptor dd = new DialogDescriptor(preferredInstrFilterPanel,
-                                                         ((SimpleFilter) selectedInstrumentationFilter).getFilterName(), true,
+        final DialogDescriptor dd = new DialogDescriptor(preferredInstrFilterPanel, MessageFormat.format(SHOW_FILTER_CAPTION, new Object[] {
+                                                         ((SimpleFilter) selectedInstrumentationFilter).getFilterName() }), true,
                                                          new Object[] {
                                                              preferredInstrFilterPanel.OPEN_IN_QUICKFILTER_BUTTON,
                                                              preferredInstrFilterPanel.CLOSE_BUTTON
@@ -807,15 +805,15 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
         }
 
         filterCombo.setSelectedIndex(itemToSelect);
-        selectedInstrumentationFilter = filterCombo.getSelectedItem(); // in case original selectedInstrFilter not found
 
         updateComboLinks();
     }
 
     private void updateComboLinks() {
         selectedInstrumentationFilter = filterCombo.getSelectedItem();
+        if (selectedInstrumentationFilter == null) selectedInstrumentationFilter = SimpleFilter.NO_FILTER;
 
-        if (selectedInstrumentationFilter.equals(quickFilter)) {
+        if (quickFilter.equals(selectedInstrumentationFilter)) {
             showFilterLink.setVisible(false);
             editFilterLink.setVisible(true);
         } else if ((preferredInstrFilters != null) && preferredInstrFilters.contains(selectedInstrumentationFilter)) {
@@ -873,7 +871,7 @@ public class CPUSettingsBasicPanel extends DefaultSettingsPanel implements Actio
             partOfAppHintLink.setText(labelText, labelFocusedText);
         }
 
-        if ((quickFilter != null) && (filterCombo.getSelectedItem() != null) && filterCombo.getSelectedItem().equals(quickFilter)
+        if (quickFilter != null && quickFilter.equals(filterCombo.getSelectedItem())
                 && (quickFilter.getFilterValue().trim().length() == 0)) {
             quickFilterSubmitOK = false;
         }
