@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -233,10 +233,10 @@ public class MemorySettingsAdvancedPanel extends DefaultSettingsPanel implements
     }
 
     public void setRecordStackTrace(boolean record) {
-        recordStackTracesLabel.setEnabled(record && runGCCheckbox.isEnabled()); // Check for preset
-        fullDepthRadio.setEnabled(record && runGCCheckbox.isEnabled()); // Check for preset
-        definedDepthRadio.setEnabled(record && runGCCheckbox.isEnabled()); // Check for preset
-        defineDepthSpinner.setEnabled(record && runGCCheckbox.isEnabled()); // Check for preset
+        recordStackTracesLabel.setEnabled(record && threadsMonitoringCheckbox.isEnabled()); // Check for preset
+        fullDepthRadio.setEnabled(record && threadsMonitoringCheckbox.isEnabled()); // Check for preset
+        definedDepthRadio.setEnabled(record && threadsMonitoringCheckbox.isEnabled()); // Check for preset
+        defineDepthSpinner.setEnabled(record && threadsMonitoringCheckbox.isEnabled()); // Check for preset
         updateEnabling();
     }
 
@@ -244,6 +244,10 @@ public class MemorySettingsAdvancedPanel extends DefaultSettingsPanel implements
         runGCCheckbox.setSelected(runGC);
     }
 
+    public void updateRunGC(boolean allocOnly) {
+        runGCCheckbox.setEnabled(!allocOnly && threadsMonitoringCheckbox.isEnabled()); // Check for preset
+    }
+
     public boolean getRunGC() {
         return runGCCheckbox.isSelected();
     }
