@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -72,6 +72,7 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import java.util.Properties;
+import java.util.concurrent.CountDownLatch;
 import javax.swing.BorderFactory;
 import javax.swing.Icon;
 import javax.swing.ImageIcon;
@@ -211,11 +212,11 @@ public class SelectProfilingTask extends JPanel implements TaskChooser.Listener,
 
     // --- UI components declaration ---------------------------------------------
     private static final Image BACKGROUND_IMAGE = UIUtils.isNimbus() ? null : ImageUtilities.loadImage("org/netbeans/modules/profiler/ui/stp/resources/sptBar.png"); // NOI18N
-    private static final Icon MONITOR_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/ui/resources/monitoring.png")); // NOI18N
-    private static final Icon CPU_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/ui/resources/cpu.png")); // NOI18N
-    private static final Icon MEMORY_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/ui/resources/memory.png")); // NOI18N
-    private static final Icon RUN_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/actions/resources/runButton.gif")); // NOI18N
-    private static final Icon ATTACH_ICON = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/actions/resources/attachButton.gif")); // NOI18N
+    private static final Icon MONITOR_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/ui/resources/monitoring.png", false); // NOI18N
+    private static final Icon CPU_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/ui/resources/cpu.png", false); // NOI18N
+    private static final Icon MEMORY_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/ui/resources/memory.png", false); // NOI18N
+    private static final Icon RUN_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/actions/resources/runButton.gif", false); // NOI18N
+    private static final Icon ATTACH_ICON = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/actions/resources/attachButton.gif", false); // NOI18N
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -307,32 +308,52 @@ public class SelectProfilingTask extends JPanel implements TaskChooser.Listener,
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
     public static Configuration selectAttachProfilerTask() { // profiledFile = null, enableOverride = false,
+        // Running this code in EDT would cause deadlock
+        assert !SwingUtilities.isEventDispatchThread();
 
-        SelectProfilingTask spt = getDefault();
+        final SelectProfilingTask spt = getDefault();
         spt.setSubmitButton(spt.attachButton);
         spt.setupAttachProfiler();
 
         spt.dd = new DialogDescriptor(spt, ATTACH_DIALOG_CAPTION, true, new Object[] { spt.attachButton, spt.cancelButton },
                                       spt.attachButton, 0, null, null);
 
-        Dialog d = ProfilerDialogs.createDialog(spt.dd);
-        d.pack();
-        d.setVisible(true);
+        final CountDownLatch latch = new CountDownLatch(1);
 
-        Configuration result = null;
+        SwingUtilities.invokeLater(new Runnable() {
 
-        if (spt.dd.getValue() == spt.attachButton) {
-            result = new Configuration( spt.createFinalSettings(), spt.getAttachSettings());
+            public void run() {
+                Dialog d = ProfilerDialogs.createDialog(spt.dd);
+                d.pack();
+                d.setVisible(true);
+                latch.countDown();
+            }
+        });
+
+        try {
+            latch.await();
+
+            Configuration result = null;
+
+            if (spt.dd.getValue() == spt.attachButton) {
+                result = new Configuration(spt.createFinalSettings(), spt.getAttachSettings());
+            }
+
+            spt.cleanup();
+
+            return result;
+
+        } catch (InterruptedException e) {
+            Thread.currentThread().interrupt();
         }
-
-        spt.cleanup();
-
-        return result;
+        return null;
     }
 
     public static Configuration selectModifyProfilingTask(FileObject profiledFile, boolean isAttach) { // profiledFile = null, enableOverride = false,
+        // Running this code in EDT would cause deadlock
+        assert !SwingUtilities.isEventDispatchThread();
 
-        SelectProfilingTask spt = getDefault();
+        final SelectProfilingTask spt = getDefault();
         spt.setSubmitButton(spt.modifyButton);
         spt.setupModifyProfiling(profiledFile, isAttach);
 
@@ -340,24 +361,43 @@ public class SelectProfilingTask extends JPanel implements TaskChooser.Listener,
                                       MessageFormat.format(MODIFY_DIALOG_CAPTION, new Object[] { Utils.getProjectName() }),
                                       true, new Object[] { spt.modifyButton, spt.cancelButton }, spt.modifyButton, 0, null, null);
 
-        Dialog d = ProfilerDialogs.createDialog(spt.dd);
-        d.pack();
-        d.setVisible(true);
+        final CountDownLatch latch = new CountDownLatch(1);
 
-        Configuration result = null;
+        SwingUtilities.invokeLater(new Runnable() {
 
-        if (spt.dd.getValue() == spt.modifyButton) {
-            result = new Configuration( spt.createFinalSettings(), null);
+            public void run() {
+                Dialog d = ProfilerDialogs.createDialog(spt.dd);
+                d.pack();
+                d.setVisible(true);
+                latch.countDown();
+            }
+        });
+
+        try {
+            latch.await();
+
+            Configuration result = null;
+
+            if (spt.dd.getValue() == spt.modifyButton) {
+                result = new Configuration(spt.createFinalSettings(), null);
+            }
+
+            spt.cleanup();
+
+            return result;
+
+        } catch (InterruptedException e) {
+            Thread.currentThread().interrupt();
         }
-
-        spt.cleanup();
-
-        return result;
+        return null;
     }
 
     // --- Public interface ------------------------------------------------------
     public static Configuration selectProfileProjectTask(FileObject profiledFile, boolean enableOverride) {
-        SelectProfilingTask spt = getDefault();
+        // Running this code in EDT would cause deadlock
+        assert !SwingUtilities.isEventDispatchThread();
+        
+        final SelectProfilingTask spt = getDefault();
         spt.setSubmitButton(spt.runButton);
         spt.setupProfileProject(profiledFile, enableOverride);
 
@@ -365,27 +405,43 @@ public class SelectProfilingTask extends JPanel implements TaskChooser.Listener,
         spt.dd = new DialogDescriptor(spt, MessageFormat.format(PROFILE_DIALOG_CAPTION, new Object[] { targetName }), true,
                                       new Object[] { spt.runButton, spt.cancelButton }, spt.runButton, 0, null, null);
 
-        Dialog d = ProfilerDialogs.createDialog(spt.dd);
-        d.pack();
-        d.setVisible(true);
+        final CountDownLatch latch = new CountDownLatch(1);
 
-        Configuration result = null;
+        SwingUtilities.invokeLater(new Runnable() {
 
-        if (spt.dd.getValue() == spt.runButton) {
-            ProfilingSettings settings = spt.createFinalSettings();
-            if (settings.getOverrideGlobalSettings()) {
-                String workDir = settings.getWorkingDir().trim();
-                if (workDir.length() != 0 && !new java.io.File(workDir).exists()) {
-                    settings.setWorkingDir(""); // NOI18N
-                    NetBeansProfiler.getDefaultNB().displayWarning(WORKDIR_INVALID_MSG);
-                }
+            public void run() {
+                Dialog d = ProfilerDialogs.createDialog(spt.dd);
+                d.getAccessibleContext().setAccessibleDescription(d.getTitle());
+                d.pack();
+                d.setVisible(true);
+                latch.countDown();
             }
-            result = new Configuration( settings, null);
+        });
+
+        try {
+            latch.await();
+
+            Configuration result = null;
+
+            if (spt.dd.getValue() == spt.runButton) {
+                ProfilingSettings settings = spt.createFinalSettings();
+                if (settings.getOverrideGlobalSettings()) {
+                    String workDir = settings.getWorkingDir().trim();
+                    if (workDir.length() != 0 && !new java.io.File(workDir).exists()) {
+                        settings.setWorkingDir(""); // NOI18N
+                        NetBeansProfiler.getDefaultNB().displayWarning(WORKDIR_INVALID_MSG);
+                    }
+                }
+                result = new Configuration(settings, null);
+            }
+
+            spt.cleanup();
+
+            return result;
+        } catch (InterruptedException e) {
+            Thread.currentThread().interrupt();
         }
-
-        spt.cleanup();
-
-        return result;
+        return null;
     }
 
     public HelpCtx getHelpCtx() {
