@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -58,8 +58,8 @@ import org.openide.NotifyDescriptor;
 import org.openide.filesystems.FileLock;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
-import org.openide.filesystems.Repository;
 import org.openide.modules.InstalledFileLocator;
+import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.windows.TopComponent;
@@ -72,13 +72,15 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.lang.reflect.InvocationTargetException;
+import java.net.URL;
 import java.text.MessageFormat;
 import java.util.*;
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
 import javax.swing.event.ListSelectionEvent;
 import javax.swing.event.ListSelectionListener;
-
+import org.openide.filesystems.Repository;
+import org.openide.filesystems.URLMapper;
 
 
 /**
@@ -109,7 +111,7 @@ public final class IDEUtils {
     private static final String LIST_ACCESS_NAME = NbBundle.getMessage(IDEUtils.class, "IDEUtils_ListAccessName"); //NOI18N
     private static final String OK_BUTTON_TEXT = NbBundle.getMessage(IDEUtils.class, "IDEUtils_OkButtonText"); //NOI18N
                                                                                                                // -----
-    public static final String SETTINGS_DIR = "org-netbeans-modules-profiler"; //NOI18N
+    private static final String SETTINGS_FOR_ATTR = "settingsFor";
     private static final RequestProcessor profilerRequestProcessor = new RequestProcessor("Profiler Request Processor", 1); // NOI18N
     private static final ErrorManager profilerErrorManager = ErrorManager.getDefault().getInstance("org.netbeans.modules.profiler"); // NOI18N
 
@@ -169,29 +171,20 @@ public final class IDEUtils {
 
     public static FileObject getProjectSettingsFolder(boolean create)
                                                throws IOException {
-
+  
             return getSettingsFolder(true);
     }
 
-    public static String getServicesDir() {
-        // Need to search also for localized filters-default, there is a possibility that default en filters-default.xml won't be in Services directory.
-        final File dir = InstalledFileLocator.getDefault()
-                                             .locate("config/Services/filters-default.xml", "org.netbeans.modules.profiler", true); //NOI18N
-
-        if (dir == null) {
-            return null;
-        } else {
-            return dir.getParentFile().getPath();
-        }
-    }
+    private static final String PROFILER_FOLDER = "NBProfiler/Config";  // NOI18N
+    private static final String SETTINGS_FOLDER = "Settings";   // NOI18N
 
     public static FileObject getSettingsFolder(final boolean create)
                                         throws IOException {
-        final FileObject folder = Repository.getDefault().getDefaultFileSystem().findResource("Services"); //NOI18N
-        FileObject settingsFolder = folder.getFileObject(SETTINGS_DIR, null);
+        final FileObject folder = FileUtil.getConfigFile(PROFILER_FOLDER);
+        FileObject settingsFolder = folder.getFileObject(SETTINGS_FOLDER, null);
 
         if ((settingsFolder == null) && create) {
-            settingsFolder = folder.createFolder(SETTINGS_DIR);
+            settingsFolder = folder.createFolder(SETTINGS_FOLDER);
         }
 
         return settingsFolder;
